@@ -1,4 +1,5 @@
 from functools import partial
+from itertools import count
 
 
 def converter(fmt, size, chunk):
@@ -37,13 +38,10 @@ handlers = dict(
 )
 
 
-def dumper(path, fmt=None):
-    fmt = fmt or 'hex'
+def dumper(path, fmt='hex'):
     convert, space = handlers[fmt]
     with open(path, 'rb') as inp:
-        adr = 0
-        while True:
-            chunk = inp.read(16)
-            if not chunk: break
+        read = partial(inp.read, 16)
+        for adr, chunk in zip(count(step=16), iter(read, b'')):
             yield f'{adr:08X} {convert(chunk)}{space(chunk)}{decode(chunk)}'
-            adr += 16
+
